@@ -2,7 +2,7 @@ import argparse
 # import privateprefs as prefs
 
 # from privateprefs.privateprefs import _save
-import privateprefs.internal.data_serializer as _internal
+import privateprefs.internal.data_serializer as ds
 
 
 def _save_cli(key: str, value: str) -> None:
@@ -13,7 +13,7 @@ def _save_cli(key: str, value: str) -> None:
     :return: None
     """
     # noinspection PyProtectedMember
-    _internal.save(key, value)
+    ds.save(key, value)
     print(f"saved key='{key}' value='{value}'")
 
 
@@ -23,7 +23,7 @@ def _load_cli(key: str) -> None:
     :param key: The key to load a value from
     :return: None
     """
-    value = _internal.load(key)
+    value = ds.load(key)
     print(f"loaded key='{key}' value='{value}'")
 
 
@@ -35,11 +35,11 @@ def _delete_cli(key: str, delete_all: bool = False) -> None:
     :return: None
     """
     if delete_all:
-        _internal.delete_all()
+        ds.delete_all()
         print(f"all prefs deleted")
     else:
-        print(f"deleted key='{key}' value='{_internal.load(key)}'")
-        _internal.delete(key)
+        print(f"deleted key='{key}' value='{ds.load(key)}'")
+        ds.delete(key)
 
 
 def _list_cli() -> None:
@@ -58,9 +58,9 @@ def print_list() -> None:
     print()
     print("stored (key  :  value)")
     print("-------------------------------------------------------------")
-    d = _internal.load_dict()
+    d = ds.load_dict()
     if len(d) > 0:
-        for key, value in _internal.load_dict().items():
+        for key, value in ds.load_dict().items():
             print(key, '  :  ', value)
     else:
         print("list is empty: (no key-value pairs saved yet)")
